From: Paolo Abeni <pabeni@redhat.com>
To: David Wang <00107082@163.com>,
davem@davemloft.net, dsahern@kernel.org, edumazet@google.com,
kuba@kernel.org
Cc: netdev@vger.kernel.org, linux-kernel@vger.kernel.org
Subject: Re: [PATCH] net/ipv4/proc: Avoid usage for seq_printf() when reading /proc/net/snmp
Date: Thu, 14 Nov 2024 10:30:34 +0100 [thread overview]
Message-ID: <406c545e-8c00-406a-98f0-0e545c427b25@redhat.com> (raw)
In-Reply-To: <20241111045623.10229-1-00107082@163.com>
On 11/11/24 05:56, David Wang wrote:
> seq_printf() is costy, when reading /proc/net/snmp, profiling indicates
> seq_printf() takes more than 50% samples of snmp_seq_show():
> snmp_seq_show(97.751% 158722/162373)
> snmp_seq_show_tcp_udp.isra.0(40.017% 63515/158722)
> seq_printf(83.451% 53004/63515)
> seq_write(1.170% 743/63515)
> _find_next_bit(0.727% 462/63515)
> ...
> seq_printf(24.762% 39303/158722)
> snmp_seq_show_ipstats.isra.0(21.487% 34104/158722)
> seq_printf(85.788% 29257/34104)
> _find_next_bit(0.331% 113/34104)
> seq_write(0.235% 80/34104)
> ...
> icmpmsg_put(7.235% 11483/158722)
> seq_printf(41.714% 4790/11483)
> seq_write(2.630% 302/11483)
> ...
> Time for a million rounds of stress reading /proc/net/snmp:
> real 0m24.323s
> user 0m0.293s
> sys 0m23.679s
> On average, reading /proc/net/snmp takes 0.023ms.
> With this patch, extra costs of seq_printf() is avoided, and a million
> rounds of reading /proc/net/snmp now takes only ~15.853s:
> real 0m16.386s
> user 0m0.280s
> sys 0m15.853s
> On average, one read takes 0.015ms, a ~40% improvement.
>
> Signed-off-by: David Wang <00107082@163.com>
If the user space is really concerned with snmp access performances, I
think such information should be exposed via netlink.
Still the goal of the optimization looks doubtful. The total number of
mibs domain is constant and limited (differently from the network
devices number that in specific setup can grow a lot). Stats polling
should be a low frequency operation. Why you need to optimize it?
I don't think we should accept this change, too. And a solid explanation
should be need to introduce a netlink MIB interface.
> ---
> net/ipv4/proc.c | 116 ++++++++++++++++++++++++++++--------------------
FTR you missed mptcp.
/P
next prev parent reply other threads:[~2024-11-14 9:30 UTC|newest]
Thread overview: 4+ messages / expand[flat|nested] mbox.gz Atom feed top
2024-11-11 4:56 David Wang
2024-11-14 9:30 ` Paolo Abeni [this message]
2024-11-14 10:19 ` David Wang
2024-11-14 11:16 ` Paolo Abeni
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=406c545e-8c00-406a-98f0-0e545c427b25@redhat.com \
--to=pabeni@redhat.com \
--cc=00107082@163.com \
--cc=davem@davemloft.net \
--cc=dsahern@kernel.org \
--cc=edumazet@google.com \
--cc=kuba@kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=netdev@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®